/****************************************************************************
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *~                             IR Kernel                                    ~
 *~                         Copyright(C) 1993                                ~
 *~                       Software Kinetics Ltd.                             ~
 *~                        All Rights Reserved                               ~
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Copyright Software Kinetics Ltd.
 * 
 * Software Kinetics Ltd. has granted a licence of this software to
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve,
 * reproduce and sell the software.
 *
 * The software is provided to the user "as is" without warranty of
 * any kind.  Neither Software Kinetics Ltd. nor the National Library
 * of Canada warrants,guarantees or makes any representation regarding
 * the use, or the results of the use of the software in terms of
 * accuracy,reliability, or otherwise.  The entire risk as results and
 * performance of the software is assumed by the user. Neither
 * Software Kinetics Ltd. nor the National Library of Canada shall be
 * liable for any direct, indirect, consequential or incidental
 * damages arising out the use of software.
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
 *
 * Program: iraliset.c
 *
 * Purpose: This file contains the functions to initialize the TCP socket.
 *
 * Invocation:
 *
 * Input Arguments:
 *
 * Output/Exit Values: None
 *
 * Functions used:
 *
 * Version: Date:   93/05/12
 *          Name:   Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * Reference: IR KERNEL - TARGET PRELIMINARY SOFTWARE DESIGN DOCUMENT
 *            IR KERNEL - TARGET SOFTWARE DETAIL DESIGN DOCUMENT
 *            IR KERNEL - INTERFACE REQUIREMENTS SPECIFICATION
 *            OSI - ANSI Z39.50 DOCUMENTATION
 *
 * Notes:
 *
 * $Log: ir.h,v $
 *
 *****************************************************************************/

#include <stdio.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>
#include <arpa/inet.h>
#include <sys/errno.h>
#include "ir.h"
#include "irconst.h"
#include "irerror.h"
#include "cspliset.h"

#define MAXNAMELEN       100
#define MaxQueueSize      5

extern int errno;

/*****************************************************************************
 *
 * Function:    ira_ALI_setup
 *
 * Purpose:     This module sets up the TCP IR service berkerley socket by
 *				calling cs_PLI_setup.
 *
 * Input Arguments: irPort - TCP IR Default Service Port
 *
 * Return values:   SUCCESS - operation was completed successfully
 *                  FAILED  - operation failed
 *
 * Output Arguments: irSocket - IR Socket File Id
 *
 * External Variables:
 *
 * Function used:
 *                  cs_ALI_setup()
 *
 * Algorithm:
 *
 * Version: Date:   93/05/12
 *          Name:   Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * Reference:
 *
 * Notes:
 *
 ****************************************************************************/
int
ira_ALI_setup(irPort, irSocket)
    int irPort, *irSocket;
{

	int res;

#ifdef DEBUG_LEVEL1
    fprintf(DEBUG_FILE1, "calling ... ira_ALI_setup \n");
#endif

	res = cs_PLI_setup(irPort, irSocket);

	return(res);

}                                /* end of ira_ALI_setup  */
