/****************************************************************************
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *~                             IR Kernel                                    ~
 *~                         Copyright(C) 1993                                ~
 *~                       Software Kinetics Ltd.                             ~
 *~                        All Rights Reserved                               ~
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Copyright Software Kinetics Ltd.
 * 
 * Software Kinetics Ltd. has granted a licence of this software to
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve,
 * reproduce and sell the software.
 *
 * The software is provided to the user "as is" without warranty of
 * any kind.  Neither Software Kinetics Ltd. nor the National Library
 * of Canada warrants,guarantees or makes any representation regarding
 * the use, or the results of the use of the software in terms of
 * accuracy,reliability, or otherwise.  The entire risk as results and
 * performance of the software is assumed by the user. Neither
 * Software Kinetics Ltd. nor the National Library of Canada shall be
 * liable for any direct, indirect, consequential or incidental
 * damages arising out the use of software.
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
 *
 * Program: irserrsp.c
 *
 * Purpose: This file contains function to send the service response APDU to
 *          the target process.
 *
 * Invocation:
 *
 * Input Arguments:
 *
 * Output/Exit Values: None
 *
 * Functions used: ira_service_response()
 *
 * Version: Date:   93/05/12
 *          Name:   Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * Reference: IR KERNEL - TARGET PRELIMINARY SOFTWARE DESIGN DOCUMENT
 *            IR KERNEL - TARGET SOFTWARE DETAIL DESIGN DOCUMENT
 *            IR KERNEL - INTERFACE REQUIREMENTS SPECIFICATION
 *            OSI - ANSI Z39.50 DOCUMENTATION
 *
 * Notes:
 *
 * $Log: ir.h,v $
 *
 *****************************************************************************/

#include <stdio.h>
#include "ir.h"
#include "irconst.h"
#include "irassoc.h"
#include "irerror.h"

/*****************************************************************************
 *
 * Function: ira_service_response
 *
 * Purpose: This function sends a response APDU to the target process.
 *
 * Input Arguments:
 *                    assocId   - current association
 *
 * Return values:     SUCCESS  - APDU has been sent successfully
 *                    FAILED   - APDU transmission failed
 *
 * Output Arguments:  none
 *
 * Function used: cs_send_data()
 *
 * Version:
 *
 * References:
 *
 * Notes:
 *
 ****************************************************************************/

int
ira_service_response(assocId)
    struct assoc_struct **assocId;
{
    int result;                        /* function return result */

#ifdef DEBUG_LEVEL1
    fprintf(DEBUG_FILE1, "Calling ira_service_response ...\n");
#endif

    result = cs_send_data((*assocId)->APDU_ptr, (*assocId)->APDUsize, (*assocId)->socket_no[QRMSOCK]);

#ifdef DEBUG_LEVEL1
    if (result == SUCCESS)
        fprintf(DEBUG_FILE1, "ira_service_response: send data OK\n");
    else
        fprintf(DEBUG_FILE1, "ira_service_response: send data Failed\n");
#endif

    return (result);

}                                /* end of procedure ira_service_response */
