/****************************************************************************
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *~                             IR Kernel                                    ~
 *~                         Copyright(C) 1993                                ~
 *~                       Software Kinetics Ltd.                             ~
 *~                        All Rights Reserved                               ~
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Copyright Software Kinetics Ltd.
 * 
 * Software Kinetics Ltd. has granted a licence of this software to
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve,
 * reproduce and sell the software.
 *
 * The software is provided to the user "as is" without warranty of
 * any kind.  Neither Software Kinetics Ltd. nor the National Library
 * of Canada warrants,guarantees or makes any representation regarding
 * the use, or the results of the use of the software in terms of
 * accuracy,reliability, or otherwise.  The entire risk as results and
 * performance of the software is assumed by the user. Neither
 * Software Kinetics Ltd. nor the National Library of Canada shall be
 * liable for any direct, indirect, consequential or incidental
 * damages arising out the use of software.
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
 *
 * Program: irtgrsct.c
 *
 * Purpose: This file contains the trigger resource control service
 *          functions.
 *
 * Invocation:
 *
 * Input Arguments:
 *
 * Output/Exit Values: None
 *
 * Functions used: ir_trigger_resource_control_request()
 *
 * Algorithm:
 *
 * Version: Date:   93/05/12
 *          Name:   Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * Reference: IR KERNEL - TARGET PRELIMINARY SOFTWARE DESIGN DOCUMENT
 *            IR KERNEL - TARGET SOFTWARE DETAIL DESIGN DOCUMENT
 *            IR KERNEL - INTERFACE REQUIREMENTS SPECIFICATION
 *            OSI - ANSI Z39.50 DOCUMENTATION
 *
 * Notes:
 *
 * $Log: ir.h,v $
 *
 *****************************************************************************/

#include <stdio.h>
#include "ir.h"
#include "irerror.h"
#include "irconst.h"
#include "asn_incl.h"

/*****************************************************************************
 *
 * Function: ir_trigger_resource_control_request
 *
 * Purpose: This function receives a trigger resource control request from
 *          an Origin, validates it, and relays the APDU to the target process.
 *
 * Input Arguments:       assocId - pointer to the current association
 *                        PDU_ptr - pointer to the PDU
 *
 * Return values: SUCCESS
 *                FAILED
 *
 * Output Argument:
 *
 * External Variables:
 *
 * Function used: ira_service_request()
 *
 * Version: Date:   93/05/12
 *          Name:   Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * References:
 *
 * Notes:
 *
 ****************************************************************************/

int
ir_trigger_resource_control_request(assocId, PDU_ptr)
    struct assoc_struct **assocId;
    APDU *PDU_ptr;
{

    int result;

#ifdef DEBUG_LEVEL1
    fprintf(DEBUG_FILE1, "\n Calling ir_trigger_resource_control_request ...");
#endif

    /* validate the trigger resource control request APDU */

    /* service the trigger request */
    if (SUCCESS)
    {
        result = ira_service_request(assocId);
    }

    return (result);

}                                /* End Of Procedure
                                 * ir_trigger_resource_control_request */
